@@ -8,6 +8,7 @@ CLI_CONFIG = {
     "extras": {
         "render": "json",
     },
+    "render_pipe": {},
     "crypto_plugin": {"subcommands": ["encrypt", "decrypt"]},
     "output": {"source": "rend", "subcommands": ["decrypt"]},
     "output_file": {"subcommands": ["encrypt"]},
@@ -29,6 +30,18 @@ CONFIG = {
         "default": "fernet",
         "help": "The crypto plugin to use with acct",
     },
+    "render_pipe": {
+        "default": "jinja|yaml",
+        "help": "The render pipe to use to parse input files before they are encrypted",
+    },
+    "serial_plugin": {
+        "default": "msgpack",
+        "help": "The pop-serial plugin to use to serialize data before it is encrypted",
+    },
+    "allowed_backend_profiles": {
+        "default": None,
+        "help": "A list of backend profile names to allow, defaults to ALL",
+    },
     "output_file": {"default": None, "help": "The output file name when encrypting"},
 }
 SUBCOMMANDS = {
