@@ -1,22 +1,20 @@
+from typing import Dict
+
 import cryptography.fernet
-import dict_tools.utils
-import msgpack
 
 
-def generate_key(hub):
+def generate_key(hub) -> str:
     key = cryptography.fernet.Fernet.generate_key()
     return key.decode("utf-8")
 
 
-def encrypt(hub, data, key: str):
+def encrypt(hub, data: Dict, key: str) -> bytes:
     fernet = cryptography.fernet.Fernet(key)
-    raw = msgpack.dumps(data)
+    raw = hub.crypto.init.dump(data)
     return fernet.encrypt(raw)
 
 
-def decrypt(hub, data, key: str):
+def decrypt(hub, data: bytes, key: str) -> Dict:
     fernet = cryptography.fernet.Fernet(key)
     raw = fernet.decrypt(data)
-    serialized = msgpack.loads(raw)
-    decoded = dict_tools.utils.decode_dict(serialized)
-    return decoded
+    return hub.crypto.init.load(raw)
